@@ -6,8 +6,8 @@
 
 namespace Fm {
 
-DirListJob::DirListJob(const FilePath& path, Flags _flags, const std::shared_ptr<const HashSet>& cutFilesHashSet):
-    dir_path{path}, flags{_flags}, cutFilesHashSet_{cutFilesHashSet} {
+DirListJob::DirListJob(const FilePath& path, Flags _flags):
+    dir_path{path}, flags{_flags} {
 }
 
 void DirListJob::exec() {
@@ -106,11 +106,6 @@ _retry:
                     // Q_EMIT filesFound();
                 }
 
-                if(cutFilesHashSet_
-                        && cutFilesHashSet_->count(fileInfo->path().hash()) > 0) {
-                    fileInfo->bindCutFiles(cutFilesHashSet_);
-                }
-
                 foundFiles.push_back(std::move(fileInfo));
             }
             else {
