@@ -12,7 +12,11 @@ const char defaultGFileInfoQueryAttribs[] = "standard::*,"
                                             "access::*,"
                                             "trash::deletion-date,"
                                             "id::filesystem,"
+                                            "id::file,"
                                             "metadata::emblems,"
+                                            "mountable::can-mount,"
+                                            "mountable::can-unmount,"
+                                            "mountable::can-eject,"
                                             METADATA_TRUST;
 
 FileInfo::FileInfo() {
@@ -39,8 +43,9 @@ void FileInfo::setFromGFileInfo(const GObjectPtr<GFileInfo>& inf, const FilePath
     GIcon* gicon;
     GFileType type;
 
-    if (const char * name = g_file_info_get_name(inf.get()))
+    if(const char* name = g_file_info_get_name(inf.get())) {
         name_ = name;
+    }
 
     dispName_ = QString::fromUtf8(g_file_info_get_display_name(inf.get()));
 
@@ -132,6 +137,21 @@ void FileInfo::setFromGFileInfo(const GObjectPtr<GFileInfo>& inf, const FilePath
     isShortcut_ = (type == G_FILE_TYPE_SHORTCUT);
     isMountable_ = (type == G_FILE_TYPE_MOUNTABLE);
 
+    canMount_ = canUnmount_ = canEject_ = false;
+    if(isMountable_) {
+        if(g_file_info_has_attribute(inf.get(), G_FILE_ATTRIBUTE_MOUNTABLE_CAN_MOUNT)) {
+            canMount_ = g_file_info_get_attribute_boolean(inf.get(), G_FILE_ATTRIBUTE_MOUNTABLE_CAN_MOUNT);
+        }
+
+        if(g_file_info_has_attribute(inf.get(), G_FILE_ATTRIBUTE_MOUNTABLE_CAN_UNMOUNT)) {
+            canUnmount_ = g_file_info_get_attribute_boolean(inf.get(), G_FILE_ATTRIBUTE_MOUNTABLE_CAN_UNMOUNT);
+        }
+
+        if(g_file_info_has_attribute(inf.get(), G_FILE_ATTRIBUTE_MOUNTABLE_CAN_EJECT)) {
+            canEject_ = g_file_info_get_attribute_boolean(inf.get(), G_FILE_ATTRIBUTE_MOUNTABLE_CAN_EJECT);
+        }
+    }
+
     /* special handling for symlinks */
     if(g_file_info_get_is_symlink(inf.get())) {
         mode_ &= ~S_IFMT; /* reset type */
@@ -259,6 +279,9 @@ _file_is_symlink:
     tmp = g_file_info_get_attribute_string(inf.get(), G_FILE_ATTRIBUTE_ID_FILESYSTEM);
     filesystemId_ = g_intern_string(tmp);
 
+    tmp = g_file_info_get_attribute_string(inf.get(), G_FILE_ATTRIBUTE_ID_FILE);
+    fileId_ = g_intern_string(tmp);
+
     mtime_ = g_file_info_get_attribute_uint64(inf.get(), G_FILE_ATTRIBUTE_TIME_MODIFIED);
     atime_ = g_file_info_get_attribute_uint64(inf.get(), G_FILE_ATTRIBUTE_TIME_ACCESS);
     ctime_ = g_file_info_get_attribute_uint64(inf.get(), G_FILE_ATTRIBUTE_TIME_CHANGED);
@@ -411,7 +434,7 @@ void FileInfo::setTrustable(bool trust) const {
     if(!isExecutableType()) {
         return; // METADATA_TRUST is only for executables
     }
-    GObjectPtr<GFileInfo> info {g_file_info_new()}; // used to set only this attribute
+    GFileInfoPtr info{g_file_info_new(), false}; // used to set only this attribute
     if(trust) {
         g_file_info_set_attribute_string(info.get(), METADATA_TRUST, "true");
         g_file_info_set_attribute_string(inf_.get(), METADATA_TRUST, "true");
@@ -426,6 +449,43 @@ void FileInfo::setTrustable(bool trust) const {
                                     nullptr, nullptr);
 }
 
+void FileInfo::setEmblem(const QString& emblmeName, bool setGFileEmblem) const {
+    QByteArray str;
+    if(!emblmeName.isEmpty()) {
+        str = emblmeName.toLocal8Bit();
+        char* stringv[] = {str.data(), nullptr};
+        g_file_info_set_attribute_stringv(inf_.get(), "metadata::emblems", stringv);
+    }
+    else {
+        g_file_info_set_attribute(inf_.get(), "metadata::emblems", G_FILE_ATTRIBUTE_TYPE_INVALID, nullptr);
+    }
+    // update current emblems
+    emblems_.clear();
+    if(g_file_info_get_attribute_type(inf_.get(), "metadata::emblems") == G_FILE_ATTRIBUTE_TYPE_STRINGV) {
+        auto emblem_names = g_file_info_get_attribute_stringv(inf_.get(), "metadata::emblems");
+        if(emblem_names) {
+            auto n_emblems = g_strv_length(emblem_names);
+            for(int i = n_emblems - 1; i >= 0; --i) {
+                emblems_.emplace_front(Fm::IconInfo::fromName(emblem_names[i]));
+            }
+        }
+    }
+
+    if(setGFileEmblem) { // really give the emblem to GFile
+        GFileInfoPtr info{g_file_info_new(), false};
+        if(!str.isEmpty()) {
+            char* stringv[] = {str.data(), nullptr};
+            g_file_info_set_attribute_stringv(info.get(), "metadata::emblems", stringv);
+        }
+        else {
+            g_file_info_set_attribute(info.get(), "metadata::emblems", G_FILE_ATTRIBUTE_TYPE_INVALID, nullptr);
+        }
+        g_file_set_attributes_from_info(path().gfile().get(),
+                                        info.get(),
+                                        G_FILE_QUERY_INFO_NONE,
+                                        nullptr, nullptr);
+    }
+}
 
 bool FileInfoList::isSameType() const {
     if(!empty()) {
