@@ -25,6 +25,7 @@
 #include "fileoperation.h"
 #include "filelauncher.h"
 #include "appchooserdialog.h"
+#include "mountoperation.h"
 
 #include "customactions/fileaction.h"
 #include "customaction_p.h"
@@ -113,27 +114,6 @@ FileMenu::FileMenu(Fm::FileInfoList files, std::shared_ptr<const Fm::FileInfo> i
             g_list_free(apps);
         }
     }
-    else {
-        // add a menu-item for opening a mixed selection of files with their default apps
-        auto a = menu->addAction(tr("Default Applications"));
-        connect(a, &QAction::triggered, this, [this] {
-            if(files_.size() > 20) {
-                QMessageBox::StandardButton r = QMessageBox::question(
-                                                parentWidget() ? parentWidget()->window()
-                                                               : nullptr,
-                                                tr("Many files"),
-                                                tr("Do you want to open these %1 files?",
-                                                   nullptr,
-                                                   files_.size()).arg(files_.size()),
-                                                QMessageBox::Yes | QMessageBox::No,
-                                                QMessageBox::No);
-                if(r == QMessageBox::No) {
-                    return;
-                }
-            }
-            fileLauncher_->launchFiles(nullptr, files_);
-        });
-    }
     menu->addSeparator();
     openWithAction_ = new QAction(tr("Other Applications"), this);
     connect(openWithAction_, &QAction::triggered, this, &FileMenu::onOpenWithTriggered);
@@ -237,9 +217,55 @@ FileMenu::FileMenu(Fm::FileInfoList files, std::shared_ptr<const Fm::FileInfo> i
         addCustomActionItem(this, item);
     }
 
+
+    // mount, unmount and eject, e.g., in computer:///
+    if(files_.size() == 1) {
+        QAction* mountSeparator = nullptr;
+        if(info_ ->canMount()) {
+            mountSeparator = addSeparator();
+            QAction* action = new QAction(tr("Mount"), this);
+            connect(action, &QAction::triggered, this, [this] {
+                if(info_->canMount()) {
+                    MountOperation* op = new MountOperation(true, parentWidget());
+                    op->mountMountable(info_->path());
+                    op->wait();
+                }
+            });
+            addAction(action);
+        }
+        if(info_ ->canUnmount()) {
+            if(!mountSeparator) {
+                mountSeparator = addSeparator();
+            }
+            QAction* action = new QAction(tr("Unmount"), this);
+            connect(action, &QAction::triggered, this, [this] {
+                if(info_->canUnmount()) {
+                    MountOperation* op = new MountOperation(true, parentWidget());
+                    op->unmount(info_->path());
+                    op->wait();
+                }
+            });
+            addAction(action);
+        }
+        if(info_ ->canEject()) {
+            if(!mountSeparator) {
+                addSeparator();
+            }
+            QAction* action = new QAction(tr("Eject"), this);
+            connect(action, &QAction::triggered, this, [this] {
+                if(info_->canEject()) {
+                    MountOperation* op = new MountOperation(true, parentWidget());
+                    op->eject(info_->path());
+                    op->wait();
+                }
+            });
+            addAction(action);
+        }
+    }
+
     // archiver integration
-    // FIXME: we need to modify upstream libfm to include some Qt-based archiver programs.
-    if(!allVirtual_ && !allTrash_) {
+    if(!allVirtual_ && !allTrash_
+       && !(sameFilesystem_ && path.hasUriScheme("computer"))) {
         auto archiver = Archiver::defaultArchiver();
         if(archiver) {
             if(sameType_ && archiver->isMimeTypeSupported(mime_type->name())) {
@@ -320,6 +346,20 @@ void FileMenu::addCustomActionItem(QMenu* menu, std::shared_ptr<const FileAction
 }
 
 void FileMenu::onOpenTriggered() {
+    if(files_.size() > 20) {
+        QMessageBox::StandardButton r = QMessageBox::question(
+                                        parentWidget() ? parentWidget()->window()
+                                                        : nullptr,
+                                        tr("Many files"),
+                                        tr("Do you want to open these %1 files?",
+                                           nullptr,
+                                           files_.size()).arg(files_.size()),
+                                        QMessageBox::Yes | QMessageBox::No,
+                                        QMessageBox::No);
+        if(r == QMessageBox::No) {
+            return;
+        }
+    }
     if(fileLauncher_) {
         fileLauncher_->launchFiles(nullptr, files_);
     }
@@ -347,14 +387,17 @@ void FileMenu::onOpenWithTriggered() {
 }
 
 void FileMenu::openFilesWithApp(GAppInfo* app) {
-    GList* uris = nullptr;
+    Fm::FilePathList paths;
     for(auto& file: files_) {
-        auto uri = file->path().uri();
-        uris = g_list_prepend(uris, uri.release());
+        paths.emplace_back(file->path());
+    }
+    if(fileLauncher_) {
+        fileLauncher_->launchWithApp(nullptr, app, paths);
+    }
+    else {
+        Fm::FileLauncher launcher;
+        launcher.launchWithApp(nullptr, app, paths);
     }
-    uris = g_list_reverse(uris); // respect the original order
-    fm_app_info_launch_uris(app, uris, nullptr, nullptr);
-    g_list_free_full(uris, g_free);
 }
 
 void FileMenu::onApplicationTriggered() {
