@@ -23,6 +23,7 @@
 #include "ui_filesearch.h"
 #include <limits>
 #include <QFileDialog>
+#include <QCompleter>
 #include <utility>
 
 namespace Fm {
@@ -43,6 +44,10 @@ FileSearchDialog::FileSearchDialog(QStringList paths, QWidget* parent, Qt::Windo
     connect(ui->addPath, &QPushButton::clicked, this, &FileSearchDialog::onAddPath);
     connect(ui->removePath, &QPushButton::clicked, this, &FileSearchDialog::onRemovePath);
 
+    // the default completer is case-insensitive
+    ui->namePatterns->completer()->setCaseSensitivity(Qt::CaseSensitive);
+    ui->contentPattern->completer()->setCaseSensitivity(Qt::CaseSensitive);
+
     ui->namePatterns->setFocus();
 }
 
@@ -50,6 +55,25 @@ FileSearchDialog::~FileSearchDialog() {
     delete ui;
 }
 
+QString FileSearchDialog::namePattern() const {
+    return ui->namePatterns->currentText();
+}
+
+QString FileSearchDialog::contentPattern() const {
+    return ui->contentPattern->currentText();
+}
+
+void FileSearchDialog::addNamePatterns(const QStringList& patterns) {
+    ui->namePatterns->addItems(patterns);
+    ui->namePatterns->setCurrentIndex(-1);
+    ui->namePatterns->setCurrentText(QLatin1String("*"));
+}
+
+void FileSearchDialog::addContentPatterns(const QStringList& patterns) {
+    ui->contentPattern->addItems(patterns);
+    ui->contentPattern->setCurrentIndex(-1);
+}
+
 void FileSearchDialog::accept() {
     // build the search:/// uri
     int n = ui->listView->count();
@@ -62,11 +86,11 @@ void FileSearchDialog::accept() {
 
         fm_search_set_recursive(search, ui->recursiveSearch->isChecked());
         fm_search_set_show_hidden(search, ui->searchHidden->isChecked());
-        fm_search_set_name_patterns(search, ui->namePatterns->text().toUtf8().constData());
+        fm_search_set_name_patterns(search, ui->namePatterns->currentText().toUtf8().constData());
         fm_search_set_name_ci(search, !ui->nameCaseSensitive->isChecked());
         fm_search_set_name_regex(search, ui->nameRegExp->isChecked());
 
-        fm_search_set_content_pattern(search, ui->contentPattern->text().toUtf8().constData());
+        fm_search_set_content_pattern(search, ui->contentPattern->currentText().toUtf8().constData());
         fm_search_set_content_ci(search, !ui->contentCaseSensitive->isChecked());
         fm_search_set_content_regex(search, ui->contentRegExp->isChecked());
 
