@@ -24,6 +24,7 @@
 #include "filepropsdialog.h"
 #include "folderview.h"
 #include "utilities.h"
+#include "fileoperation.h"
 #include <cstring> // for memset
 #include <QDebug>
 #include "customaction_p.h"
@@ -43,8 +44,28 @@ FolderMenu::FolderMenu(FolderView* view, QWidget* parent):
 
     ProxyFolderModel* model = view_->model();
 
-    bool insideTrash(view_->path() && view_->path().hasUriScheme("trash"));
-    if(!insideTrash) {
+    bool insideTrash = false;
+    bool insideSearch = false;
+    if(view_->path())
+    {
+        insideTrash = view_->path().hasUriScheme("trash");
+        insideSearch = view_->path().hasUriScheme("search");
+    }
+    if(insideTrash) {
+        if(auto folder = view_->folder()) {
+            if(!folder->isEmpty()) {
+                auto trashAction = new QAction(tr("Empty Trash"), this);
+                addAction(trashAction);
+                connect(trashAction, &QAction::triggered, []() {
+                    Fm::FilePathList files;
+                    files.push_back(Fm::FilePath::fromUri("trash:///"));
+                    Fm::FileOperation::deleteFiles(std::move(files), true);
+                });
+                addSeparator();
+            }
+        }
+    }
+    else if (!insideSearch) {
         createAction_ = new QAction(tr("Create &New"), this);
         addAction(createAction_);
         createAction_->setMenu(new CreateNewMenu(view_, view_->path(), this));
@@ -56,15 +77,23 @@ FolderMenu::FolderMenu(FolderView* view, QWidget* parent):
         separator2_ = addSeparator();
     }
 
-    selectAllAction_ = new QAction(tr("Select &All"), this);
-    addAction(selectAllAction_);
-    connect(selectAllAction_, &QAction::triggered, this, &FolderMenu::onSelectAllActionTriggered);
+    auto selMode = view_->childView()->selectionMode();
+    if(selMode == QAbstractItemView::SingleSelection || selMode == QAbstractItemView::NoSelection) {
+        selectAllAction_ = nullptr;
+        invertSelectionAction_ = nullptr;
+        separator3_ = nullptr;
+    }
+    else {
+        selectAllAction_ = new QAction(tr("Select &All"), this);
+        addAction(selectAllAction_);
+        connect(selectAllAction_, &QAction::triggered, this, &FolderMenu::onSelectAllActionTriggered);
 
-    invertSelectionAction_ = new QAction(tr("Invert Selection"), this);
-    addAction(invertSelectionAction_);
-    connect(invertSelectionAction_, &QAction::triggered, this, &FolderMenu::onInvertSelectionActionTriggered);
+        invertSelectionAction_ = new QAction(tr("Invert Selection"), this);
+        addAction(invertSelectionAction_);
+        connect(invertSelectionAction_, &QAction::triggered, this, &FolderMenu::onInvertSelectionActionTriggered);
 
-    separator3_ = addSeparator();
+        separator3_ = addSeparator();
+    }
 
     sortAction_ = new QAction(tr("Sorting"), this);
     addAction(sortAction_);
