@@ -29,6 +29,7 @@
 #include "filemenu.h"
 #include "foldermenu.h"
 #include "filelauncher.h"
+#include "fileoperation.h"
 #include "utilities.h"
 #include <QTimer>
 #include <QDate>
@@ -49,7 +50,6 @@
 #include <xcb/xcb.h> // for XDS support
 #include "xdndworkaround.h" // for XDS support
 #include "folderview_p.h"
-#include "utilities.h"
 
 #include <algorithm>
 
@@ -85,6 +85,7 @@ FolderViewListView::~FolderViewListView() {
 }
 
 void FolderViewListView::startDrag(Qt::DropActions supportedActions) {
+    mouseLeftPressed_ = false; // see FolderViewListView::mouseMoveEvent
     if(movement() != Static) {
         QListView::startDrag(supportedActions);
     }
@@ -401,7 +402,7 @@ void FolderViewTreeView::setHiddenColumns(const QSet<int> &columns) {
 }
 
 void FolderViewTreeView::headerContextMenu(const QPoint &p) {
-    QMenu menu;
+    QMenu menu(header()); // a parent is needed under Wayland for correct positioning
     QAction *action = menu.addAction (tr("Auto-resize columns"));
     action->setCheckable(true);
     action->setChecked(customColumnWidths_.isEmpty());
@@ -720,8 +721,11 @@ void FolderViewTreeView::layoutColumns() {
                 // Compute the width available for the filename column
                 int filenameAvailWidth = availWidth - desiredWidth + widths.at(filenameColumn);
 
-                // Compute the minimum acceptable width for the filename column
-                int filenameMinWidth = qMin(200, sizeHintForColumn(filenameColumn));
+                // Compute the minimum acceptable width for the filename column, showing
+                // whole texts whose lengths are less than 30 times the average font width.
+                int filenameMinWidth = qMin(iconSize().width()
+                                            + 30 * opt.fontMetrics.averageCharWidth(),
+                                            sizeHintForColumn(filenameColumn));
 
                 if(filenameAvailWidth > filenameMinWidth) {
                     // Shrink the filename column to the available width
@@ -1595,23 +1599,86 @@ void FolderView::childDropEvent(QDropEvent* e) {
     }
 
     if(e->keyboardModifiers() == Qt::NoModifier) {
-        // if no key modifiers are used, popup a menu
+        // If no key modifiers are used, pop up a menu
         // to ask the user for the action he/she wants to perform.
-        Qt::DropActions actions = Qt::IgnoreAction;
+
+        // NOTE: Under Wayland, serious problems will happen if the DND menu is shown
+        // while the DND is in progress. Also, the menu needs a parent for correct positioning.
+
+        Fm::FilePath destPath;
         std::shared_ptr<const Fm::FileInfo> info = nullptr;
         if(model_) {
             QModelIndex index = view->indexAt(e->pos());
             info = model_->fileInfoFromIndex(index);
         }
-        if(!info || !info->isDir()) {
+        if(info && info->isDir()) {
+            destPath = info->path(); // drop on a subdirectory
+        }
+        else {
             info = folderInfo();
+            destPath = path(); // drop on blank area of the folder
         }
-        if(info && info->isWritableDirectory() && info->isWritable()) {
-            actions = e->possibleActions();
+
+        Fm::FilePathList srcPaths;
+        // try to get paths from the original data
+        if(e->mimeData()->hasFormat(QStringLiteral("libfm/files"))) {
+            QByteArray _data = e->mimeData()->data(QStringLiteral("libfm/files"));
+            srcPaths = pathListFromUriList(_data.data());
+        }
+        if(srcPaths.empty() && e->mimeData()->hasUrls()) {
+            srcPaths = Fm::pathListFromQUrls(e->mimeData()->urls());
+        }
+
+        if(!srcPaths.empty()) {
+            Qt::DropActions actions = Qt::IgnoreAction;
+            if(info && info->isWritableDirectory() && info->isWritable()) {
+                actions = e->possibleActions();
+            }
+            auto curPos = view->viewport()->mapToGlobal(e->pos());
+            QTimer::singleShot(0, view, [this, curPos, actions, srcPaths, destPath] {
+                Qt::DropAction action;
+                // Wayland does not see the modifier if it is pressed after dragging.
+                // Therefore, it should be checked now, when the DND is finished.
+                switch(QApplication::keyboardModifiers()) {
+                case Qt::ControlModifier:
+                    action = Qt::CopyAction;
+                    break;
+                case Qt::ShiftModifier:
+                    action = Qt::MoveAction;
+                    break;
+                case Qt::ControlModifier | Qt::ShiftModifier:
+                    action = Qt::LinkAction;
+                    break;
+                default:
+                    // a parent is needed under Wayland for correct positioning
+                    action = DndActionMenu::askUser(actions, curPos, view);
+                    break;
+                }
+
+                Q_EMIT dropIsDecided(action != Qt::IgnoreAction);
+
+                switch(action) {
+                case Qt::CopyAction:
+                    FileOperation::copyFiles(srcPaths, destPath);
+                    break;
+                case Qt::MoveAction:
+                    FileOperation::moveFiles(srcPaths, destPath);
+                    break;
+                case Qt::LinkAction:
+                    FileOperation::symlinkFiles(srcPaths, destPath);
+                    break;
+                default:
+                    break;
+                }
+            });
+            e->accept(); // prevent further event propagation
+            return;
         }
-        Qt::DropAction action = DndActionMenu::askUser(actions, view->viewport()->mapToGlobal(e->pos()));
-        e->setDropAction(action);
     }
+
+    QTimer::singleShot(0, view, [this] {
+        Q_EMIT dropIsDecided(true); // after finishing drop
+    });
 }
 
 bool FolderView::eventFilter(QObject* watched, QEvent* event) {
@@ -1950,7 +2017,7 @@ void FolderView::onFileClicked(int type, const std::shared_ptr<const Fm::FileInf
             }
         }
         if (!menu && folderInfo()) {
-            Fm::FolderMenu* folderMenu = new Fm::FolderMenu(this);
+            Fm::FolderMenu* folderMenu = new Fm::FolderMenu(this, this);
             prepareFolderMenu(folderMenu);
             menu = folderMenu;
         }
