@@ -124,7 +124,7 @@
     <message>
         <location filename="../exec-file.ui" line="99"/>
         <source>Remember for next files of this kind</source>
-        <translation type="unfinished"></translation>
+        <translation>לזכור לקבצים הבאים מהסוג הזה</translation>
     </message>
 </context>
 <context>
@@ -675,6 +675,8 @@ Do you want to replace it?</source>
         <translation>
             <numerusform>לפתוח את הקובץ הזה בגודל %1?</numerusform>
             <numerusform>לפתוח את הקבצים האלה בגודל %1?</numerusform>
+            <numerusform>לפתוח את הקבצים האלה בגודל %1?</numerusform>
+            <numerusform>לפתוח את הקבצים האלה בגודל %1?</numerusform>
         </translation>
     </message>
     <message>
@@ -801,6 +803,8 @@ Do you want to delete them instead?</source>
         <translation>
             <numerusform>למחוק את הקובץ הנבחר?</numerusform>
             <numerusform>למחוק את הקבצים הנבחרים?</numerusform>
+            <numerusform>למחוק את הקבצים הנבחרים?</numerusform>
+            <numerusform>למחוק את הקבצים הנבחרים?</numerusform>
         </translation>
     </message>
     <message numerus="yes">
@@ -809,6 +813,8 @@ Do you want to delete them instead?</source>
         <translation>
             <numerusform>להעביר את הפריט הנבחר לפח האשפה?</numerusform>
             <numerusform>להעביר את הפריטים הנבחרים לפח האשפה?</numerusform>
+            <numerusform>להעביר את הפריטים הנבחרים לפח האשפה?</numerusform>
+            <numerusform>להעביר את הפריטים הנבחרים לפח האשפה?</numerusform>
         </translation>
     </message>
 </context>
@@ -961,6 +967,8 @@ Do you want to delete them instead?</source>
         <translation>
             <numerusform>קובץ %Ln</numerusform>
             <numerusform>%Ln קבצים</numerusform>
+            <numerusform>%Ln קבצים</numerusform>
+            <numerusform>%Ln קבצים</numerusform>
         </translation>
     </message>
     <message>
